@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,15 +20,14 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.webrisk_v1.types import webrisk
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebRiskServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import WebRiskServiceGrpcAsyncIOTransport
 from .client import WebRiskServiceClient
@@ -52,35 +49,61 @@ class WebRiskServiceAsyncClient:
     parse_common_billing_account_path = staticmethod(
         WebRiskServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(WebRiskServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         WebRiskServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         WebRiskServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         WebRiskServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(WebRiskServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         WebRiskServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(WebRiskServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         WebRiskServiceClient.parse_common_location_path
     )
 
-    from_service_account_file = WebRiskServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            WebRiskServiceAsyncClient: The constructed client.
+        """
+        return WebRiskServiceClient.from_service_account_info.__func__(WebRiskServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            WebRiskServiceAsyncClient: The constructed client.
+        """
+        return WebRiskServiceClient.from_service_account_file.__func__(WebRiskServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> WebRiskServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             WebRiskServiceTransport: The transport used by the client instance.
@@ -94,12 +117,12 @@ class WebRiskServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, WebRiskServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the web risk service client.
+        """Instantiates the web risk service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -131,7 +154,6 @@ class WebRiskServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = WebRiskServiceClient(
             credentials=credentials,
             transport=transport,
@@ -160,12 +182,13 @@ class WebRiskServiceAsyncClient:
         once for each list.
 
         Args:
-            request (:class:`~.webrisk.ComputeThreatListDiffRequest`):
+            request (:class:`google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest`):
                 The request object. Describes an API diff request.
-            threat_type (:class:`~.webrisk.ThreatType`):
+            threat_type (:class:`google.cloud.webrisk_v1.types.ThreatType`):
                 Required. The threat list to update.
                 Only a single ThreatType should be
                 specified.
+
                 This corresponds to the ``threat_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -179,16 +202,17 @@ class WebRiskServiceAsyncClient:
                 ComputeThreatListDiff), this may be left
                 empty and a full database snapshot will
                 be returned.
+
                 This corresponds to the ``version_token`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            constraints (:class:`~.webrisk.ComputeThreatListDiffRequest.Constraints`):
+            constraints (:class:`google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest.Constraints`):
                 Required. The constraints associated
                 with this request.
+
                 This corresponds to the ``constraints`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -196,7 +220,7 @@ class WebRiskServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.ComputeThreatListDiffResponse:
+            google.cloud.webrisk_v1.types.ComputeThreatListDiffResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -213,7 +237,6 @@ class WebRiskServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if threat_type is not None:
             request.threat_type = threat_type
         if version_token is not None:
@@ -230,8 +253,10 @@ class WebRiskServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -261,23 +286,24 @@ class WebRiskServiceAsyncClient:
         response will be returned.
 
         Args:
-            request (:class:`~.webrisk.SearchUrisRequest`):
+            request (:class:`google.cloud.webrisk_v1.types.SearchUrisRequest`):
                 The request object. Request to check URI entries against
                 threatLists.
             uri (:class:`str`):
                 Required. The URI to be checked for
                 matches.
+
                 This corresponds to the ``uri`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[~.webrisk.ThreatType]`):
+            threat_types (:class:`Sequence[google.cloud.webrisk_v1.types.ThreatType]`):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
+
                 This corresponds to the ``threat_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -285,7 +311,7 @@ class WebRiskServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.SearchUrisResponse:
+            google.cloud.webrisk_v1.types.SearchUrisResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -302,10 +328,8 @@ class WebRiskServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if uri is not None:
             request.uri = uri
-
         if threat_types:
             request.threat_types.extend(threat_types)
 
@@ -318,8 +342,10 @@ class WebRiskServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -349,7 +375,7 @@ class WebRiskServiceAsyncClient:
         match of a threat.
 
         Args:
-            request (:class:`~.webrisk.SearchHashesRequest`):
+            request (:class:`google.cloud.webrisk_v1.types.SearchHashesRequest`):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
             hash_prefix (:class:`bytes`):
@@ -357,17 +383,18 @@ class WebRiskServiceAsyncClient:
                 significant 4-32 bytes of a SHA256 hash.
                 For JSON requests, this field is
                 base64-encoded.
+
                 This corresponds to the ``hash_prefix`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[~.webrisk.ThreatType]`):
+            threat_types (:class:`Sequence[google.cloud.webrisk_v1.types.ThreatType]`):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
+
                 This corresponds to the ``threat_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -375,7 +402,7 @@ class WebRiskServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.SearchHashesResponse:
+            google.cloud.webrisk_v1.types.SearchHashesResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -392,10 +419,8 @@ class WebRiskServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if hash_prefix is not None:
             request.hash_prefix = hash_prefix
-
         if threat_types:
             request.threat_types.extend(threat_types)
 
@@ -408,8 +433,10 @@ class WebRiskServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -441,24 +468,25 @@ class WebRiskServiceAsyncClient:
         visibility can use this method.
 
         Args:
-            request (:class:`~.webrisk.CreateSubmissionRequest`):
+            request (:class:`google.cloud.webrisk_v1.types.CreateSubmissionRequest`):
                 The request object. Request to send a potentially phishy
                 URI to WebRisk.
             parent (:class:`str`):
                 Required. The name of the project that is making the
                 submission. This string is in the format
                 "projects/{project_number}".
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            submission (:class:`~.webrisk.Submission`):
+            submission (:class:`google.cloud.webrisk_v1.types.Submission`):
                 Required. The submission that
                 contains the content of the phishing
                 report.
+
                 This corresponds to the ``submission`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -466,7 +494,7 @@ class WebRiskServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.Submission:
+            google.cloud.webrisk_v1.types.Submission:
                 Wraps a URI that might be displaying
                 phishing content.
 
@@ -485,7 +513,6 @@ class WebRiskServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if submission is not None:
