@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,18 +21,17 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.webrisk_v1.types import webrisk
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebRiskServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import WebRiskServiceGrpcTransport
 from .transports.grpc_asyncio import WebRiskServiceGrpcAsyncIOTransport
@@ -55,7 +52,7 @@ class WebRiskServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = WebRiskServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[WebRiskServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -80,7 +77,8 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -112,10 +110,27 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            WebRiskServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -124,7 +139,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            WebRiskServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -134,16 +149,17 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     @property
     def transport(self) -> WebRiskServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            WebRiskServiceTransport: The transport used by the client instance.
+            WebRiskServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -156,7 +172,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -167,7 +183,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -178,7 +194,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -189,7 +205,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -203,12 +219,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebRiskServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the web risk service client.
+        """Instantiates the web risk service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -216,10 +232,10 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.WebRiskServiceTransport]): The
+            transport (Union[str, WebRiskServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -255,21 +271,18 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -281,12 +294,14 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -301,8 +316,8 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -312,9 +327,13 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def compute_threat_list_diff(
@@ -338,16 +357,17 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         once for each list.
 
         Args:
-            request (:class:`~.webrisk.ComputeThreatListDiffRequest`):
+            request (google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest):
                 The request object. Describes an API diff request.
-            threat_type (:class:`~.webrisk.ThreatType`):
+            threat_type (google.cloud.webrisk_v1.types.ThreatType):
                 Required. The threat list to update.
                 Only a single ThreatType should be
                 specified.
+
                 This corresponds to the ``threat_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            version_token (:class:`bytes`):
+            version_token (bytes):
                 The current version token of the
                 client for the requested list (the
                 client version that was received from
@@ -357,16 +377,17 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 ComputeThreatListDiff), this may be left
                 empty and a full database snapshot will
                 be returned.
+
                 This corresponds to the ``version_token`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            constraints (:class:`~.webrisk.ComputeThreatListDiffRequest.Constraints`):
+            constraints (google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest.Constraints):
                 Required. The constraints associated
                 with this request.
+
                 This corresponds to the ``constraints`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -374,7 +395,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.ComputeThreatListDiffResponse:
+            google.cloud.webrisk_v1.types.ComputeThreatListDiffResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -393,10 +414,8 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, webrisk.ComputeThreatListDiffRequest):
             request = webrisk.ComputeThreatListDiffRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if threat_type is not None:
                 request.threat_type = threat_type
             if version_token is not None:
@@ -432,23 +451,24 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         response will be returned.
 
         Args:
-            request (:class:`~.webrisk.SearchUrisRequest`):
+            request (google.cloud.webrisk_v1.types.SearchUrisRequest):
                 The request object. Request to check URI entries against
                 threatLists.
-            uri (:class:`str`):
+            uri (str):
                 Required. The URI to be checked for
                 matches.
+
                 This corresponds to the ``uri`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[~.webrisk.ThreatType]`):
+            threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
+
                 This corresponds to the ``threat_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -456,7 +476,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.SearchUrisResponse:
+            google.cloud.webrisk_v1.types.SearchUrisResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -475,15 +495,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, webrisk.SearchUrisRequest):
             request = webrisk.SearchUrisRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if uri is not None:
                 request.uri = uri
-
-            if threat_types:
-                request.threat_types.extend(threat_types)
+            if threat_types is not None:
+                request.threat_types = threat_types
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -513,25 +530,26 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         match of a threat.
 
         Args:
-            request (:class:`~.webrisk.SearchHashesRequest`):
+            request (google.cloud.webrisk_v1.types.SearchHashesRequest):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
-            hash_prefix (:class:`bytes`):
+            hash_prefix (bytes):
                 A hash prefix, consisting of the most
                 significant 4-32 bytes of a SHA256 hash.
                 For JSON requests, this field is
                 base64-encoded.
+
                 This corresponds to the ``hash_prefix`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[~.webrisk.ThreatType]`):
+            threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
+
                 This corresponds to the ``threat_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -539,7 +557,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.SearchHashesResponse:
+            google.cloud.webrisk_v1.types.SearchHashesResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -558,15 +576,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, webrisk.SearchHashesRequest):
             request = webrisk.SearchHashesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if hash_prefix is not None:
                 request.hash_prefix = hash_prefix
-
-            if threat_types:
-                request.threat_types.extend(threat_types)
+            if threat_types is not None:
+                request.threat_types = threat_types
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -598,24 +613,25 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         visibility can use this method.
 
         Args:
-            request (:class:`~.webrisk.CreateSubmissionRequest`):
+            request (google.cloud.webrisk_v1.types.CreateSubmissionRequest):
                 The request object. Request to send a potentially phishy
                 URI to WebRisk.
-            parent (:class:`str`):
+            parent (str):
                 Required. The name of the project that is making the
                 submission. This string is in the format
                 "projects/{project_number}".
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            submission (:class:`~.webrisk.Submission`):
+            submission (google.cloud.webrisk_v1.types.Submission):
                 Required. The submission that
                 contains the content of the phishing
                 report.
+
                 This corresponds to the ``submission`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -623,7 +639,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.Submission:
+            google.cloud.webrisk_v1.types.Submission:
                 Wraps a URI that might be displaying
                 phishing content.
 
@@ -644,10 +660,8 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, webrisk.CreateSubmissionRequest):
             request = webrisk.CreateSubmissionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if submission is not None:
