@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -62,9 +59,8 @@ class CompressionType(proto.Enum):
 
 class ComputeThreatListDiffRequest(proto.Message):
     r"""Describes an API diff request.
-
     Attributes:
-        threat_type (~.webrisk.ThreatType):
+        threat_type (google.cloud.webrisk_v1.types.ThreatType):
             Required. The threat list to update. Only a
             single ThreatType should be specified.
         version_token (bytes):
@@ -75,14 +71,13 @@ class ComputeThreatListDiffRequest(proto.Message):
             the first time calling ComputeThreatListDiff),
             this may be left empty and a full database
             snapshot will be returned.
-        constraints (~.webrisk.ComputeThreatListDiffRequest.Constraints):
+        constraints (google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest.Constraints):
             Required. The constraints associated with
             this request.
     """
 
     class Constraints(proto.Message):
         r"""The constraints for this diff.
-
         Attributes:
             max_diff_entries (int):
                 The maximum size in number of entries. The diff will not
@@ -94,38 +89,33 @@ class ComputeThreatListDiffRequest(proto.Message):
                 willing to have in the local database. This should be a
                 power of 2 between 2\ **10 and 2**\ 20. If zero, no database
                 size limit is set.
-            supported_compressions (Sequence[~.webrisk.CompressionType]):
+            supported_compressions (Sequence[google.cloud.webrisk_v1.types.CompressionType]):
                 The compression types supported by the
                 client.
         """
 
-        max_diff_entries = proto.Field(proto.INT32, number=1)
-
-        max_database_entries = proto.Field(proto.INT32, number=2)
-
+        max_diff_entries = proto.Field(proto.INT32, number=1,)
+        max_database_entries = proto.Field(proto.INT32, number=2,)
         supported_compressions = proto.RepeatedField(
             proto.ENUM, number=3, enum="CompressionType",
         )
 
     threat_type = proto.Field(proto.ENUM, number=1, enum="ThreatType",)
-
-    version_token = proto.Field(proto.BYTES, number=2)
-
+    version_token = proto.Field(proto.BYTES, number=2,)
     constraints = proto.Field(proto.MESSAGE, number=3, message=Constraints,)
 
 
 class ComputeThreatListDiffResponse(proto.Message):
     r"""
-
     Attributes:
-        response_type (~.webrisk.ComputeThreatListDiffResponse.ResponseType):
+        response_type (google.cloud.webrisk_v1.types.ComputeThreatListDiffResponse.ResponseType):
             The type of response. This may indicate that
             an action must be taken by the client when the
             response is received.
-        additions (~.webrisk.ThreatEntryAdditions):
+        additions (google.cloud.webrisk_v1.types.ThreatEntryAdditions):
             A set of entries to add to a local threat
             type's list.
-        removals (~.webrisk.ThreatEntryRemovals):
+        removals (google.cloud.webrisk_v1.types.ThreatEntryRemovals):
             A set of entries to remove from a local
             threat type's list. This field may be empty.
         new_version_token (bytes):
@@ -133,14 +123,14 @@ class ComputeThreatListDiffResponse(proto.Message):
             by the client and passed into the next call of
             ComputeThreatListDiff as 'version_token'. A separate version
             token should be stored and used for each threatList.
-        checksum (~.webrisk.ComputeThreatListDiffResponse.Checksum):
+        checksum (google.cloud.webrisk_v1.types.ComputeThreatListDiffResponse.Checksum):
             The expected SHA256 hash of the client state;
             that is, of the sorted list of all hashes
             present in the database after applying the
             provided diff. If the client state doesn't match
             the expected state, the client must discard this
             diff and retry later.
-        recommended_next_diff (~.timestamp.Timestamp):
+        recommended_next_diff (google.protobuf.timestamp_pb2.Timestamp):
             The soonest the client should wait before
             issuing any diff request. Querying sooner is
             unlikely to produce a meaningful diff. Waiting
@@ -157,7 +147,6 @@ class ComputeThreatListDiffResponse(proto.Message):
 
     class Checksum(proto.Message):
         r"""The expected state of a client's local database.
-
         Attributes:
             sha256 (bytes):
                 The SHA256 hash of the client state; that is,
@@ -165,63 +154,55 @@ class ComputeThreatListDiffResponse(proto.Message):
                 database.
         """
 
-        sha256 = proto.Field(proto.BYTES, number=1)
+        sha256 = proto.Field(proto.BYTES, number=1,)
 
     response_type = proto.Field(proto.ENUM, number=4, enum=ResponseType,)
-
     additions = proto.Field(proto.MESSAGE, number=5, message="ThreatEntryAdditions",)
-
     removals = proto.Field(proto.MESSAGE, number=6, message="ThreatEntryRemovals",)
-
-    new_version_token = proto.Field(proto.BYTES, number=7)
-
+    new_version_token = proto.Field(proto.BYTES, number=7,)
     checksum = proto.Field(proto.MESSAGE, number=8, message=Checksum,)
-
     recommended_next_diff = proto.Field(
-        proto.MESSAGE, number=2, message=timestamp.Timestamp,
+        proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
     )
 
 
 class SearchUrisRequest(proto.Message):
     r"""Request to check URI entries against threatLists.
-
     Attributes:
         uri (str):
             Required. The URI to be checked for matches.
-        threat_types (Sequence[~.webrisk.ThreatType]):
+        threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
             Required. The ThreatLists to search in.
             Multiple ThreatLists may be specified.
     """
 
-    uri = proto.Field(proto.STRING, number=1)
-
+    uri = proto.Field(proto.STRING, number=1,)
     threat_types = proto.RepeatedField(proto.ENUM, number=2, enum="ThreatType",)
 
 
 class SearchUrisResponse(proto.Message):
     r"""
-
     Attributes:
-        threat (~.webrisk.SearchUrisResponse.ThreatUri):
+        threat (google.cloud.webrisk_v1.types.SearchUrisResponse.ThreatUri):
             The threat list matches. This may be empty if
             the URI is on no list.
     """
 
     class ThreatUri(proto.Message):
         r"""Contains threat information on a matching uri.
-
         Attributes:
-            threat_types (Sequence[~.webrisk.ThreatType]):
+            threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
                 The ThreatList this threat belongs to.
-            expire_time (~.timestamp.Timestamp):
+            expire_time (google.protobuf.timestamp_pb2.Timestamp):
                 The cache lifetime for the returned match.
                 Clients must not cache this response past this
                 timestamp to avoid false positives.
         """
 
         threat_types = proto.RepeatedField(proto.ENUM, number=1, enum="ThreatType",)
-
-        expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
+        expire_time = proto.Field(
+            proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
+        )
 
     threat = proto.Field(proto.MESSAGE, number=1, message=ThreatUri,)
 
@@ -235,24 +216,22 @@ class SearchHashesRequest(proto.Message):
             A hash prefix, consisting of the most
             significant 4-32 bytes of a SHA256 hash. For
             JSON requests, this field is base64-encoded.
-        threat_types (Sequence[~.webrisk.ThreatType]):
+        threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
             Required. The ThreatLists to search in.
             Multiple ThreatLists may be specified.
     """
 
-    hash_prefix = proto.Field(proto.BYTES, number=1)
-
+    hash_prefix = proto.Field(proto.BYTES, number=1,)
     threat_types = proto.RepeatedField(proto.ENUM, number=2, enum="ThreatType",)
 
 
 class SearchHashesResponse(proto.Message):
     r"""
-
     Attributes:
-        threats (Sequence[~.webrisk.SearchHashesResponse.ThreatHash]):
+        threats (Sequence[google.cloud.webrisk_v1.types.SearchHashesResponse.ThreatHash]):
             The full hashes that matched the requested
             prefixes. The hash will be populated in the key.
-        negative_expire_time (~.timestamp.Timestamp):
+        negative_expire_time (google.protobuf.timestamp_pb2.Timestamp):
             For requested entities that did not match the
             threat list, how long to cache the response
             until.
@@ -260,31 +239,29 @@ class SearchHashesResponse(proto.Message):
 
     class ThreatHash(proto.Message):
         r"""Contains threat information on a matching hash.
-
         Attributes:
-            threat_types (Sequence[~.webrisk.ThreatType]):
+            threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
                 The ThreatList this threat belongs to.
                 This must contain at least one entry.
             hash_ (bytes):
                 A 32 byte SHA256 hash. This field is in
                 binary format. For JSON requests, hashes are
                 base64-encoded.
-            expire_time (~.timestamp.Timestamp):
+            expire_time (google.protobuf.timestamp_pb2.Timestamp):
                 The cache lifetime for the returned match.
                 Clients must not cache this response past this
                 timestamp to avoid false positives.
         """
 
         threat_types = proto.RepeatedField(proto.ENUM, number=1, enum="ThreatType",)
-
-        hash_ = proto.Field(proto.BYTES, number=2)
-
-        expire_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+        hash_ = proto.Field(proto.BYTES, number=2,)
+        expire_time = proto.Field(
+            proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        )
 
     threats = proto.RepeatedField(proto.MESSAGE, number=1, message=ThreatHash,)
-
     negative_expire_time = proto.Field(
-        proto.MESSAGE, number=2, message=timestamp.Timestamp,
+        proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
     )
 
 
@@ -294,11 +271,11 @@ class ThreatEntryAdditions(proto.Message):
     response.
 
     Attributes:
-        raw_hashes (Sequence[~.webrisk.RawHashes]):
+        raw_hashes (Sequence[google.cloud.webrisk_v1.types.RawHashes]):
             The raw SHA256-formatted entries.
             Repeated to allow returning sets of hashes with
             different prefix sizes.
-        rice_hashes (~.webrisk.RiceDeltaEncoding):
+        rice_hashes (google.cloud.webrisk_v1.types.RiceDeltaEncoding):
             The encoded 4-byte prefixes of SHA256-formatted entries,
             using a Golomb-Rice encoding. The hashes are converted to
             uint32, sorted in ascending order, then delta encoded and
@@ -306,17 +283,15 @@ class ThreatEntryAdditions(proto.Message):
     """
 
     raw_hashes = proto.RepeatedField(proto.MESSAGE, number=1, message="RawHashes",)
-
     rice_hashes = proto.Field(proto.MESSAGE, number=2, message="RiceDeltaEncoding",)
 
 
 class ThreatEntryRemovals(proto.Message):
     r"""Contains the set of entries to remove from a local database.
-
     Attributes:
-        raw_indices (~.webrisk.RawIndices):
+        raw_indices (google.cloud.webrisk_v1.types.RawIndices):
             The raw removal indices for a local list.
-        rice_indices (~.webrisk.RiceDeltaEncoding):
+        rice_indices (google.cloud.webrisk_v1.types.RiceDeltaEncoding):
             The encoded local, lexicographically-sorted list indices,
             using a Golomb-Rice encoding. Used for sending compressed
             removal indices. The removal indices (uint32) are sorted in
@@ -325,20 +300,18 @@ class ThreatEntryRemovals(proto.Message):
     """
 
     raw_indices = proto.Field(proto.MESSAGE, number=1, message="RawIndices",)
-
     rice_indices = proto.Field(proto.MESSAGE, number=2, message="RiceDeltaEncoding",)
 
 
 class RawIndices(proto.Message):
     r"""A set of raw indices to remove from a local list.
-
     Attributes:
         indices (Sequence[int]):
             The indices to remove from a
             lexicographically-sorted local list.
     """
 
-    indices = proto.RepeatedField(proto.INT32, number=1)
+    indices = proto.RepeatedField(proto.INT32, number=1,)
 
 
 class RawHashes(proto.Message):
@@ -365,9 +338,8 @@ class RawHashes(proto.Message):
             are base64-encoded.
     """
 
-    prefix_size = proto.Field(proto.INT32, number=1)
-
-    raw_hashes = proto.Field(proto.BYTES, number=2)
+    prefix_size = proto.Field(proto.INT32, number=1,)
+    raw_hashes = proto.Field(proto.BYTES, number=2,)
 
 
 class RiceDeltaEncoding(proto.Message):
@@ -393,42 +365,36 @@ class RiceDeltaEncoding(proto.Message):
             Golomb-Rice coder.
     """
 
-    first_value = proto.Field(proto.INT64, number=1)
-
-    rice_parameter = proto.Field(proto.INT32, number=2)
-
-    entry_count = proto.Field(proto.INT32, number=3)
-
-    encoded_data = proto.Field(proto.BYTES, number=4)
+    first_value = proto.Field(proto.INT64, number=1,)
+    rice_parameter = proto.Field(proto.INT32, number=2,)
+    entry_count = proto.Field(proto.INT32, number=3,)
+    encoded_data = proto.Field(proto.BYTES, number=4,)
 
 
 class Submission(proto.Message):
     r"""Wraps a URI that might be displaying phishing content.
-
     Attributes:
         uri (str):
             Required. The URI that is being reported for
             phishing content to be analyzed.
     """
 
-    uri = proto.Field(proto.STRING, number=1)
+    uri = proto.Field(proto.STRING, number=1,)
 
 
 class CreateSubmissionRequest(proto.Message):
     r"""Request to send a potentially phishy URI to WebRisk.
-
     Attributes:
         parent (str):
             Required. The name of the project that is making the
             submission. This string is in the format
             "projects/{project_number}".
-        submission (~.webrisk.Submission):
+        submission (google.cloud.webrisk_v1.types.Submission):
             Required. The submission that contains the
             content of the phishing report.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     submission = proto.Field(proto.MESSAGE, number=2, message="Submission",)
 
 
