@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,15 +20,14 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.webrisk_v1beta1.types import webrisk
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebRiskServiceV1Beta1Transport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import WebRiskServiceV1Beta1GrpcAsyncIOTransport
 from .client import WebRiskServiceV1Beta1Client
@@ -52,24 +49,20 @@ class WebRiskServiceV1Beta1AsyncClient:
     parse_common_billing_account_path = staticmethod(
         WebRiskServiceV1Beta1Client.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(WebRiskServiceV1Beta1Client.common_folder_path)
     parse_common_folder_path = staticmethod(
         WebRiskServiceV1Beta1Client.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         WebRiskServiceV1Beta1Client.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         WebRiskServiceV1Beta1Client.parse_common_organization_path
     )
-
     common_project_path = staticmethod(WebRiskServiceV1Beta1Client.common_project_path)
     parse_common_project_path = staticmethod(
         WebRiskServiceV1Beta1Client.parse_common_project_path
     )
-
     common_location_path = staticmethod(
         WebRiskServiceV1Beta1Client.common_location_path
     )
@@ -77,12 +70,42 @@ class WebRiskServiceV1Beta1AsyncClient:
         WebRiskServiceV1Beta1Client.parse_common_location_path
     )
 
-    from_service_account_file = WebRiskServiceV1Beta1Client.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            WebRiskServiceV1Beta1AsyncClient: The constructed client.
+        """
+        return WebRiskServiceV1Beta1Client.from_service_account_info.__func__(WebRiskServiceV1Beta1AsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            WebRiskServiceV1Beta1AsyncClient: The constructed client.
+        """
+        return WebRiskServiceV1Beta1Client.from_service_account_file.__func__(WebRiskServiceV1Beta1AsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> WebRiskServiceV1Beta1Transport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             WebRiskServiceV1Beta1Transport: The transport used by the client instance.
@@ -97,12 +120,12 @@ class WebRiskServiceV1Beta1AsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, WebRiskServiceV1Beta1Transport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the web risk service v1 beta1 client.
+        """Instantiates the web risk service v1 beta1 client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -134,7 +157,6 @@ class WebRiskServiceV1Beta1AsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = WebRiskServiceV1Beta1Client(
             credentials=credentials,
             transport=transport,
@@ -156,9 +178,9 @@ class WebRiskServiceV1Beta1AsyncClient:
         r"""Gets the most recent threat list diffs.
 
         Args:
-            request (:class:`~.webrisk.ComputeThreatListDiffRequest`):
+            request (:class:`google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest`):
                 The request object. Describes an API diff request.
-            threat_type (:class:`~.webrisk.ThreatType`):
+            threat_type (:class:`google.cloud.webrisk_v1beta1.types.ThreatType`):
                 The ThreatList to update.
                 This corresponds to the ``threat_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -168,16 +190,17 @@ class WebRiskServiceV1Beta1AsyncClient:
                 client for the requested list (the
                 client version that was received from
                 the last successful diff).
+
                 This corresponds to the ``version_token`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            constraints (:class:`~.webrisk.ComputeThreatListDiffRequest.Constraints`):
+            constraints (:class:`google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest.Constraints`):
                 Required. The constraints associated
                 with this request.
+
                 This corresponds to the ``constraints`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -185,7 +208,7 @@ class WebRiskServiceV1Beta1AsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.ComputeThreatListDiffResponse:
+            google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -202,7 +225,6 @@ class WebRiskServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if threat_type is not None:
             request.threat_type = threat_type
         if version_token is not None:
@@ -219,8 +241,10 @@ class WebRiskServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -246,22 +270,23 @@ class WebRiskServiceV1Beta1AsyncClient:
         given threatList.
 
         Args:
-            request (:class:`~.webrisk.SearchUrisRequest`):
+            request (:class:`google.cloud.webrisk_v1beta1.types.SearchUrisRequest`):
                 The request object. Request to check URI entries against
                 threatLists.
             uri (:class:`str`):
                 Required. The URI to be checked for
                 matches.
+
                 This corresponds to the ``uri`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[~.webrisk.ThreatType]`):
+            threat_types (:class:`Sequence[google.cloud.webrisk_v1beta1.types.ThreatType]`):
                 Required. The ThreatLists to search
                 in.
+
                 This corresponds to the ``threat_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -269,7 +294,7 @@ class WebRiskServiceV1Beta1AsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.SearchUrisResponse:
+            google.cloud.webrisk_v1beta1.types.SearchUrisResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -286,10 +311,8 @@ class WebRiskServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if uri is not None:
             request.uri = uri
-
         if threat_types:
             request.threat_types.extend(threat_types)
 
@@ -302,8 +325,10 @@ class WebRiskServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -333,7 +358,7 @@ class WebRiskServiceV1Beta1AsyncClient:
         match of a threat.
 
         Args:
-            request (:class:`~.webrisk.SearchHashesRequest`):
+            request (:class:`google.cloud.webrisk_v1beta1.types.SearchHashesRequest`):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
             hash_prefix (:class:`bytes`):
@@ -341,16 +366,17 @@ class WebRiskServiceV1Beta1AsyncClient:
                 significant 4-32 bytes of a SHA256 hash.
                 For JSON requests, this field is
                 base64-encoded.
+
                 This corresponds to the ``hash_prefix`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[~.webrisk.ThreatType]`):
+            threat_types (:class:`Sequence[google.cloud.webrisk_v1beta1.types.ThreatType]`):
                 Required. The ThreatLists to search
                 in.
+
                 This corresponds to the ``threat_types`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -358,7 +384,7 @@ class WebRiskServiceV1Beta1AsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.webrisk.SearchHashesResponse:
+            google.cloud.webrisk_v1beta1.types.SearchHashesResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -375,10 +401,8 @@ class WebRiskServiceV1Beta1AsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if hash_prefix is not None:
             request.hash_prefix = hash_prefix
-
         if threat_types:
             request.threat_types.extend(threat_types)
 
@@ -391,8 +415,10 @@ class WebRiskServiceV1Beta1AsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
